Enum ConsoleEvents
pub enum ConsoleEvents {
Show 22 variants
log(log),
logs(logs),
log_address(log_address),
log_bytes32(log_bytes32),
log_int(log_int),
log_uint(log_uint),
log_bytes(log_bytes),
log_string(log_string),
log_array_0(log_array_0),
log_array_1(log_array_1),
log_array_2(log_array_2),
log_named_address(log_named_address),
log_named_bytes32(log_named_bytes32),
log_named_decimal_int(log_named_decimal_int),
log_named_decimal_uint(log_named_decimal_uint),
log_named_int(log_named_int),
log_named_uint(log_named_uint),
log_named_bytes(log_named_bytes),
log_named_string(log_named_string),
log_named_array_0(log_named_array_0),
log_named_array_1(log_named_array_1),
log_named_array_2(log_named_array_2),
}Expand description
Container for all the Console events.
Variants
log(log)
logs(logs)
log_address(log_address)
log_bytes32(log_bytes32)
log_int(log_int)
log_uint(log_uint)
log_bytes(log_bytes)
log_string(log_string)
log_array_0(log_array_0)
log_array_1(log_array_1)
log_array_2(log_array_2)
log_named_address(log_named_address)
log_named_bytes32(log_named_bytes32)
log_named_decimal_int(log_named_decimal_int)
log_named_decimal_uint(log_named_decimal_uint)
log_named_int(log_named_int)
log_named_uint(log_named_uint)
log_named_bytes(log_named_bytes)
log_named_string(log_named_string)
log_named_array_0(log_named_array_0)
log_named_array_1(log_named_array_1)
log_named_array_2(log_named_array_2)
Implementations
impl ConsoleEvents
impl ConsoleEvents
pub const SELECTORS: &'static [[u8; 32]]
pub const SELECTORS: &'static [[u8; 32]]
All the selectors of this enum.
Note that the selectors might not be in the same order as the variants. No guarantees are made about the order of the selectors.
Prefer using SolInterface methods instead.
pub const VARIANT_NAMES: &'static [&'static str]
pub const VARIANT_NAMES: &'static [&'static str]
The names of the variants in the same order as SELECTORS.
pub const SIGNATURES: &'static [&'static str]
pub const SIGNATURES: &'static [&'static str]
The signatures in the same order as SELECTORS.
pub fn signature_by_selector(selector: [u8; 32]) -> Option<&'static str>
pub fn signature_by_selector(selector: [u8; 32]) -> Option<&'static str>
Returns the signature for the given selector, if known.
pub fn name_by_selector(selector: [u8; 32]) -> Option<&'static str>
pub fn name_by_selector(selector: [u8; 32]) -> Option<&'static str>
Returns the enum variant name for the given selector, if known.
impl ConsoleEvents
impl ConsoleEvents
pub fn log(val: String) -> ConsoleEvents
pub fn log(val: String) -> ConsoleEvents
Creates a log event.
event log(string)pub fn logs(val: Bytes) -> ConsoleEvents
pub fn logs(val: Bytes) -> ConsoleEvents
Creates a logs event.
event logs(bytes)pub fn log_address(val: Address) -> ConsoleEvents
pub fn log_address(val: Address) -> ConsoleEvents
Creates a log_address event.
event log_address(address)pub fn log_bytes_32(val: FixedBytes<32>) -> ConsoleEvents
pub fn log_bytes_32(val: FixedBytes<32>) -> ConsoleEvents
Creates a log_bytes32 event.
event log_bytes32(bytes32)pub fn log_int(val: Signed<256, 4>) -> ConsoleEvents
pub fn log_int(val: Signed<256, 4>) -> ConsoleEvents
Creates a log_int event.
event log_int(int256)pub fn log_uint(val: Uint<256, 4>) -> ConsoleEvents
pub fn log_uint(val: Uint<256, 4>) -> ConsoleEvents
Creates a log_uint event.
event log_uint(uint256)pub fn log_bytes(val: Bytes) -> ConsoleEvents
pub fn log_bytes(val: Bytes) -> ConsoleEvents
Creates a log_bytes event.
event log_bytes(bytes)pub fn log_string(val: String) -> ConsoleEvents
pub fn log_string(val: String) -> ConsoleEvents
Creates a log_string event.
event log_string(string)pub fn log_array_0(val: Vec<Uint<256, 4>>) -> ConsoleEvents
pub fn log_array_0(val: Vec<Uint<256, 4>>) -> ConsoleEvents
Creates a log_array_0 event.
event log_array(uint256[])pub fn log_array_1(val: Vec<Signed<256, 4>>) -> ConsoleEvents
pub fn log_array_1(val: Vec<Signed<256, 4>>) -> ConsoleEvents
Creates a log_array_1 event.
event log_array(int256[])pub fn log_array_2(val: Vec<Address>) -> ConsoleEvents
pub fn log_array_2(val: Vec<Address>) -> ConsoleEvents
Creates a log_array_2 event.
event log_array(address[])pub fn log_named_address(key: String, val: Address) -> ConsoleEvents
pub fn log_named_address(key: String, val: Address) -> ConsoleEvents
Creates a log_named_address event.
event log_named_address(string,address)pub fn log_named_bytes_32(key: String, val: FixedBytes<32>) -> ConsoleEvents
pub fn log_named_bytes_32(key: String, val: FixedBytes<32>) -> ConsoleEvents
Creates a log_named_bytes32 event.
event log_named_bytes32(string,bytes32)pub fn log_named_decimal_int(
key: String,
val: Signed<256, 4>,
decimals: Uint<256, 4>,
) -> ConsoleEvents
pub fn log_named_decimal_int( key: String, val: Signed<256, 4>, decimals: Uint<256, 4>, ) -> ConsoleEvents
Creates a log_named_decimal_int event.
event log_named_decimal_int(string,int256,uint256)pub fn log_named_decimal_uint(
key: String,
val: Uint<256, 4>,
decimals: Uint<256, 4>,
) -> ConsoleEvents
pub fn log_named_decimal_uint( key: String, val: Uint<256, 4>, decimals: Uint<256, 4>, ) -> ConsoleEvents
Creates a log_named_decimal_uint event.
event log_named_decimal_uint(string,uint256,uint256)pub fn log_named_int(key: String, val: Signed<256, 4>) -> ConsoleEvents
pub fn log_named_int(key: String, val: Signed<256, 4>) -> ConsoleEvents
Creates a log_named_int event.
event log_named_int(string,int256)pub fn log_named_uint(key: String, val: Uint<256, 4>) -> ConsoleEvents
pub fn log_named_uint(key: String, val: Uint<256, 4>) -> ConsoleEvents
Creates a log_named_uint event.
event log_named_uint(string,uint256)pub fn log_named_bytes(key: String, val: Bytes) -> ConsoleEvents
pub fn log_named_bytes(key: String, val: Bytes) -> ConsoleEvents
Creates a log_named_bytes event.
event log_named_bytes(string,bytes)pub fn log_named_string(key: String, val: String) -> ConsoleEvents
pub fn log_named_string(key: String, val: String) -> ConsoleEvents
Creates a log_named_string event.
event log_named_string(string,string)pub fn log_named_array_0(key: String, val: Vec<Uint<256, 4>>) -> ConsoleEvents
pub fn log_named_array_0(key: String, val: Vec<Uint<256, 4>>) -> ConsoleEvents
Creates a log_named_array_0 event.
event log_named_array(string,uint256[])pub fn log_named_array_1(key: String, val: Vec<Signed<256, 4>>) -> ConsoleEvents
pub fn log_named_array_1(key: String, val: Vec<Signed<256, 4>>) -> ConsoleEvents
Creates a log_named_array_1 event.
event log_named_array(string,int256[])pub fn log_named_array_2(key: String, val: Vec<Address>) -> ConsoleEvents
pub fn log_named_array_2(key: String, val: Vec<Address>) -> ConsoleEvents
Creates a log_named_array_2 event.
event log_named_array(string,address[])Trait Implementations
impl Clone for ConsoleEvents
impl Clone for ConsoleEvents
fn clone(&self) -> ConsoleEvents
fn clone(&self) -> ConsoleEvents
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreimpl Display for ConsoleEvents
impl Display for ConsoleEvents
impl IntoLogData for ConsoleEvents
impl IntoLogData for ConsoleEvents
fn to_log_data(&self) -> LogData
fn to_log_data(&self) -> LogData
LogData] object.fn into_log_data(self) -> LogData
fn into_log_data(self) -> LogData
LogData] object.impl SolEventInterface for ConsoleEvents
impl SolEventInterface for ConsoleEvents
fn decode_raw_log(
topics: &[FixedBytes<32>],
data: &[u8],
) -> Result<ConsoleEvents, Error>
fn decode_raw_log( topics: &[FixedBytes<32>], data: &[u8], ) -> Result<ConsoleEvents, Error>
fn decode_log(log: &Log) -> Result<Log<Self>, Error>
fn decode_log(log: &Log) -> Result<Log<Self>, Error>